@@ -3,15 +3,14 @@ import logging
 
 import click
 
-from .add import cli_add
+
 from .copy import cli_copy
-from .create import cli_create
-from .delete import cli_delete
+from .manage import cli_manage
 from .download import cli_download
-from .list import cli_list
 from .upload import cli_upload
 from .user import cli_user
 from .view import cli_view
+from .search import cli_search
 from geoseeq.vc.cli import cli_vc
 
 logger = logging.getLogger('geoseeq_api')
@@ -24,21 +23,30 @@ logger.addHandler(handler)
 def main():
     pass
 
+main.add_command(cli_download)
+main.add_command(cli_upload)
+main.add_command(cli_manage)
+main.add_command(cli_view)
+main.add_command(cli_search)
 
 @main.command()
 def version():
     """Print the version of the Geoseeq API being used."""
-    click.echo('0.1.13')  # remember to update setup
+    click.echo('0.2.20')  # remember to update setup
 
 
+@main.group('advanced')
+def cli_advanced():
+    """Advanced commands."""
+    pass
+
+cli_advanced.add_command(cli_copy)
+cli_advanced.add_command(cli_user)
+
+@cli_advanced.group('experimental')
+def cli_experimental():
+    """Experimental commands."""
+    pass
+
+cli_experimental.add_command(cli_vc)
 
-main.add_command(cli_add)
-main.add_command(cli_create)
-main.add_command(cli_download)
-main.add_command(cli_list)
-main.add_command(cli_upload)
-main.add_command(cli_user)
-main.add_command(cli_delete)
-main.add_command(cli_copy)
-main.add_command(cli_vc)
-main.add_command(cli_view)
